@@ -116,7 +116,9 @@ class MakeAppWorkDir:
                 self.msg(f"\t{path} already exists.")
             else:
                 os.makedirs(path)
-                open(os.path.join(path, '__init__.py'), 'w').write('#\n')
+                with open(os.path.join(path, '__init__.py'), 'w',
+                          encoding='ascii') as initFile:
+                    initFile.write('#\n')
                 self.msg(f"\t{path} created.")
 
     def copyConfigFiles(self):
@@ -157,14 +159,14 @@ class MakeAppWorkDir:
         self.msg("Setting the library directories...")
         wsgiScript = os.path.join(self._workDir, 'Scripts', 'WSGIScript.py')
         if os.path.isfile(wsgiScript):
-            with open(wsgiScript) as f:
+            with open(wsgiScript, encoding='utf-8') as f:
                 script = f.read()
             if 'libDirs = []' not in script:
                 self.msg("\tWarning: Unexpected WSGI script")
             else:
                 script = script.replace(
                     'libDirs = []', f'libDirs = {self._libraryDirs!r}')
-                with open(wsgiScript, 'w') as f:
+                with open(wsgiScript, 'w', encoding='utf-8') as f:
                     f.write(script)
         else:
             self.msg("\tWarning: Cannot find WSGI script.")
@@ -186,21 +188,22 @@ class MakeAppWorkDir:
         else:
             self.msg(f"\t{contextDir}")
             os.makedirs(contextDir)
-        for name in exampleContext:
+        for name, source in exampleContext.items():
             filename = os.path.join(contextDir, name)
             if os.path.exists(filename):
                 self.msg(f"\t{filename} already exists.")
             else:
                 self.msg(f"\t{filename}")
-                open(filename, "w").write(exampleContext[name])
+                with open(filename, "w", encoding='ascii') as sourceFile:
+                    sourceFile.write(source)
         self.msg("Updating config for default context...")
-        filename = os.path.join(
-            self._workDir, 'Configs', 'Application.config')
+        filename = os.path.join(self._workDir, 'Configs', 'Application.config')
         self.msg(f"\t{filename}")
-        content = open(filename).readlines()
+        with open(filename, encoding='utf-8') as configFile:
+            configLines = configFile.readlines()
         foundContext = 0
-        with open(filename, 'w') as output:
-            for line in content:
+        with open(filename, 'w', encoding='utf-8') as output:
+            for line in configLines:
                 contextName = self._contextName
                 if line.startswith(
                         f"Contexts[{contextName!r}] = {configDir!r}\n"):
@@ -226,7 +229,7 @@ class MakeAppWorkDir:
         if os.path.exists(filename):
             existed = True
         else:
-            with open(filename, 'w') as f:
+            with open(filename, 'w', encoding='ascii') as f:
                 f.write(ignore)
         if existed:
             self.msg("\tDid not change existing .gitignore file.")
